<?php
/**
 * Plugin Name: WooCommerce Store Pickup (EasyToolsWP)
 * Description: Adds a "Store Pickup" shipping method based on specified postcodes.
 * Version: 1.0.3
 * Author: EasyToolsWP
 */

// Prevent direct access to the file
if (!defined('ABSPATH')) {
    exit;
}

// Ensure WooCommerce is active before running the plugin
function etwp_woocommerce_active_check() {
    if (class_exists('WooCommerce')) {
        // Add the shipping method
        function etwp_add_shipping_method($methods) {
            $methods['etwp_storedelivery'] = 'WC_ETWP_StoreDelivery_Shipping_Method';
            return $methods;
        }
        add_filter('woocommerce_shipping_methods', 'etwp_add_shipping_method');

        // Define the shipping method class
        if (!class_exists('WC_ETWP_StoreDelivery_Shipping_Method')) {
            class WC_ETWP_StoreDelivery_Shipping_Method extends WC_Shipping_Method {
                
                public function __construct() {
                    $this->id                 = 'etwp_storedelivery'; 
                    $this->method_title       = __('Store Pickup (EasyTools)', 'etwp_storedelivery');
                    $this->method_description = __('Allows customers to choose store pickup based on their postcode.', 'etwp_storedelivery'); 
                    
                    $this->enabled            = "yes";
                    $this->title              = __("Store Pickup (EasyTools)", 'etwp_storedelivery');

                    $this->init();
                }
                
                // Initialize form fields and settings
                public function init() {
                    $this->init_form_fields();
                    $this->init_settings();

                    $this->title        = $this->get_option('title');
                    $this->cost         = $this->get_option('cost');
                    $this->postcodes    = $this->get_option('postcodes');
                    $this->description  = $this->get_option('description'); // Get the description option

                    // Save settings
                    add_action('woocommerce_update_options_shipping_' . $this->id, array($this, 'process_admin_options'));
                }
                
                // Define the fields for the shipping method settings
                public function init_form_fields() {
                    $this->form_fields = array(
                        'enabled' => array(
                            'title'   => __('Enable', 'etwp_storedelivery'),
                            'type'    => 'checkbox',
                            'label'   => __('Enable Store Pickup (EasyTools)', 'etwp_storedelivery'),
                            'default' => 'yes',
                        ),
                        'title' => array(
                            'title'       => __('Title', 'etwp_storedelivery'),
                            'type'        => 'text',
                            'description' => __('This controls the title the user sees during checkout.', 'etwp_storedelivery'),
                            'default'     => __('Store Pickup (EasyTools)', 'etwp_storedelivery'),
                            'desc_tip'    => true,
                        ),
                        'cost' => array(
                            'title'       => __('Cost', 'etwp_storedelivery'),
                            'type'        => 'text',
                            'description' => __('Set the cost for store pickup.', 'etwp_storedelivery'),
                            'default'     => '0',
                            'desc_tip'    => true,
                        ),
                        'postcodes' => array(
                            'title'       => __('Postcodes', 'etwp_storedelivery'),
                            'type'        => 'textarea',
                            'description' => __('Enter the postcodes where store pickup is available, separated by commas.', 'etwp_storedelivery'),
                            'default'     => '',
                            'desc_tip'    => true,
                        ),
                        'description' => array(
                            'title'       => __('Description', 'etwp_storedelivery'),
                            'type'        => 'textarea',
                            'description' => __('This description will appear under the store pickup option at checkout.', 'etwp_storedelivery'),
                            'default'     => '',
                            'desc_tip'    => true,
                        ),
                    );
                }

                // Calculate shipping based on postcode
                public function calculate_shipping($package = array()) {
                    $postcodes = array_map('trim', explode(',', $this->postcodes));
                    $current_postcode = WC()->customer->get_shipping_postcode();

                    if (in_array($current_postcode, $postcodes)) {
                        $rate = array(
                            'id'    => $this->id,
                            'label' => $this->title,
                            'cost'  => $this->cost,
                            'calc_tax' => 'per_item',
                        );

                        // Add the description to the shipping rate
                        $rate['meta_data'] = array('description' => $this->description);

                        $this->add_rate($rate);
                    }
                }
            }
        }

        // Display the description under the shipping method at checkout
        function etwp_display_shipping_description($label, $method) {
            if ($method->method_id === 'etwp_storedelivery' && isset($method->meta_data['description'])) {
                $description = '<p class="description">' . esc_html($method->meta_data['description']) . '</p>';
                return $label . $description;
            }
            return $label;
        }
        add_filter('woocommerce_cart_shipping_method_full_label', 'etwp_display_shipping_description', 10, 2);
    }
}
add_action('plugins_loaded', 'etwp_woocommerce_active_check', 20);
